@@ -5,14 +5,14 @@ from src.utils.calc import Calc
 
 
 class StampManager(object):
-
     def __init__(self):
         self.browser = Browser()
         self.driver = self.browser.driver
 
     def stamp(self, method):
         if self.login() and method in dir(self):
-            getattr(self, method)()
+            if (fun := getattr(self, method)):
+                fun()
             self.exit()
 
     def login(self):
